@@ -1,6 +1,6 @@
 package Object::Simple;
 
-our $VERSION = '3.18';
+our $VERSION = '3.1801';
 
 use strict;
 use warnings;
@@ -201,8 +201,8 @@ B<Fast and less memory>. Fast C<new> and accessor method. Memory saving implemen
   has foo => sub { OtherClass->new };
   
   # Create accessors at once
-  has [qw/foo bar baz/];
-  has [qw/foo bar baz/] => 0;
+  has ['foo', 'bar', 'baz'];
+  has ['foo', 'bar', 'baz'] => 0;
   
 Create object.
 
@@ -220,19 +220,18 @@ Create object.
 
 Inheritance
   
-  # Foo.pm
   package Foo;
   use Object::Simple -base;
   
-  # Bar.pm
+  # Bar inherit Foo
   package Bar;
   use Object::Simple 'Foo';
   
-  # Bar.pm (another way 1 to inherit, This is Object::Simple original)
+  # Another way to inherit(This is Object::Simple original)
   package Bar;
   use Object::Simple -base => 'Foo';
 
-  # Bar.pm (another way 2 to inherit, This is Object::Simple original)
+  # Another way to inherit (This is Object::Simple original)
   use Foo -base;
 
 =head1 DESCRIPTION
@@ -316,8 +315,8 @@ the return value become default value.
 
 You can create multiple accessors at once.
 
-  has [qw/foo bar baz/];
-  has [qw/foo bar baz/] => 0;
+  has ['foo', 'bar', 'baz'];
+  has ['foo', 'bar', 'baz'] => 0;
 
 =head2 2. Override method
 
@@ -404,17 +403,15 @@ Use Point3D class.
   $point->z(9);
   $point->clear;
 
-=head2 4. What is Object-Oriented programing?
+=head1 WHAT IS OBJECT-ORIENTED PROGRAMING?
 
-I introduce concepts of Object-Oriented programing.
+I introduce essence of Object-Oriented programing.
 
-=head3 Inheritance
-
-I explain the essence of Object-Oriented programing.
+=head2 1. Inheritance
 
 First concept is inheritance.
 Inheritance means that
-if Class Q inherit Class P, Class Q use all methods of class P.
+if Class Q inherit Class P, Class Q call all methods of class P.
 
   +---+
   | P | Base class
@@ -425,13 +422,13 @@ if Class Q inherit Class P, Class Q use all methods of class P.
   +---+   have method3
 
 Class Q inherits Class P,
-Q can use all methods of P in addition to methods of Q.
+Q can call all methods of P in addition to methods of Q.
 
-In other words, Q can use
+In other words, Q can call
 C<method1>, C<method2>, and C<method3>
 
-You can use C<-base> option to inherit class.
-  
+You can inherit other class by the following way.
+
   # P.pm
   package P;
   use Object::Simple -base;
@@ -460,7 +457,7 @@ If you know what method the object(or class) can use, use C<can> method
   SomeClass->can('method1');
   $obj->can('method1');
 
-=head3 Encapsulation
+=head2 2. Encapsulation
 
 Second concept is encapsulation.
 Encapsulation means that
@@ -472,7 +469,7 @@ Create accessor and use it to keep this rule.
   my $value = $obj->foo;
   $obj->foo(1);
 
-=head3 Polymorphism
+=head2 3. Polymorphism
 
 Third concept is polymorphism.
 Polymorphism is divided into two concepts,
@@ -507,10 +504,11 @@ Q C<method1> override P C<method1>.
   my $obj_b = Q->new;
   $obj_q->method1;
 
-If you want to use super class method from sub class,
+If you want to call super class method from sub class,
 use SUPER pseudo-class.
 
   package Q;
+  use Object::Simple 'P';
   
   sub method1 {
     my $self = shift;
@@ -531,11 +529,14 @@ you have learned Object-Oriented programming primary parts.
 Create accessor.
   
   has 'foo';
-  has [qw/foo bar baz/];
+  has ['foo', 'bar', 'baz'];
   has foo => 1;
   has foo => sub { {} };
 
-Create accessor. C<has> receive
+  has ['foo', 'bar', 'baz'];
+  has ['foo', 'bar', 'baz'] => 0;
+
+C<has> function receive
 accessor name and default value.
 Default value is optional.
 If you want to create multiple accessors at once,
@@ -553,19 +554,15 @@ Get and set a value.
 If a default value is specified and the value is not exists,
 you can get default value.
 
-If a value is set, the accessor return self object.
-So you can set a value repeatedly.
+Setter return invocant. so you can do chained call.
 
   $obj->foo(1)->bar(2);
 
-You can create all accessors at once.
-
-  has [qw/foo bar baz/];
-
 =head1 METHODS
 
 =head2 new
 
+  my $obj = Object::Simple->new;
   my $obj = Object::Simple->new(foo => 1, bar => 2);
   my $obj = Object::Simple->new({foo => 1, bar => 2});
 
@@ -575,14 +572,15 @@ hash or hash reference as arguments.
 =head2 attr
 
   __PACKAGE__->attr('foo');
-  __PACKAGE__->attr([qw/foo bar baz/]);
+  __PACKAGE__->attr(['foo', 'bar', 'baz']);
   __PACKAGE__->attr(foo => 1);
   __PACKAGE__->attr(foo => sub { {} });
 
-  __PACKAGE__->attr([qw/foo bar baz/]);
+  __PACKAGE__->attr(['foo', 'bar', 'baz']);
+  __PACKAGE__->attr(['foo', 'bar', 'baz'] => 0);
 
 Create accessor.
-C<attr> method usage is equal to C<has> method.
+C<attr> method usage is equal to C<has> function.
 
 =head1 OPTIONS
 
@@ -599,12 +597,11 @@ and import C<has> function.
 
 strict and warnings is automatically enabled.
 
-You can inherit class.
+If you want to inherit class, let's write the following way.
   
   # Bar inherit Foo
   package Bar;
   use Object::Simple 'Foo';
-  
 
 You can also use the following syntax. This is Object::Simple only.
 
@@ -631,19 +628,33 @@ If you want to use multiple inheritance or role, these methods is needed.
 
 But I strongly recommend you use only single inheritance in object-oriented programming. Single inheritance is clean and readable.
 
-If you use only single inheritance, Perl can call destructor in correct order,
-and if you create custom constructor, you can call constructor in correct order.
+If you use only single inheritance,
+You can create custom constructor and call constructors in correct order.
+and You can create custom destructor and call destructors in correct order,
+
 Creating custom constructor is very very easy. There is nothing difficult.
     
-    # Custom constructor
-    sub new {
-      # Call super class constructor
-      my $self = shift->SUPER::new(@_);
-      
-      # What you want
-      
-      return $self;
-    }
+  # Custom constructor
+  sub new {
+    # At first Call super class constructor. Next do what you want
+    my $self = shift->SUPER::new(@_);
+    
+    # What you want
+    
+    return $self;
+  }
+  
+  # Custom destructor
+  sub DESTROY {
+    my $self = shift;
+    
+    # What you want
+
+    # At first, do what you want, Next call super class destructor
+    $selft->SUPER::DESTROY;
+    
+    return $self;
+  }
 
 =head2 Object::Simple is fastest OO module?
 
@@ -704,11 +715,11 @@ EXPERIMENTAL functionality will be changed without warnings.
 =head1 BUGS
 
 Tell me the bugs
-by mail or github L<http://github.com/yuki-kimoto/Object-Simple>
+by mail(C<< <kimoto.yuki at gmail.com> >>) or github L<http://github.com/yuki-kimoto/Object-Simple>
 
 =head1 AUTHOR
 
-Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
+Yuki Kimoto(C<< <kimoto.yuki at gmail.com> >>)
 
 I'm pleasure if you send message for cheer. I can get power by only your messages!
 
